componenttools.extend_left_in_parent_of_component_and_grow_spanners
===================================================================

.. autofunction:: abjad.tools.componenttools.extend_left_in_parent_of_component_and_grow_spanners
